@@ -1,9 +1,7 @@
 
-require(sp) || stop("package sp qequired")
 
-local({
-
-    if (FALSE) {
+if (FALSE && requireNamespace("sp", quietly = TRUE)) {
+    local({
         con <- url("http://biogeo.ucdavis.edu/data/gadm2/R/CHE_adm0.RData")
         load(con)
         close(con)
@@ -27,17 +25,15 @@ local({
         m1 <- l_layer(p, gadm, label="Swiss Cantons", parent=g1,
                       color="", linecolor="red")
         
-                                        #    ## name the layers
+        #    ## name the layers
         cantons <- gadm@data$NAME_1[gadm@plotOrder]
         
         for (i in 1:length(m1)) {
             sapply(m1[[i]], function(l)l_layer_relabel(p, l, cantons[i]))
         }
-        
-    } else {
-        cat(paste0('loon demo l_map_sp should be evaluated by hand\nFind the demo file at: ',
-                   system.file('demo','l_map_sp.R', package='loon'),'\n'))
-    }
-    ## l_aspect(p) <- 5/3
-    
-})
+        ## l_aspect(p) <- 5/3
+    })
+} else {
+    cat(paste0('loon demo l_map_sp should be evaluated by hand\nFind the demo file at: ',
+               system.file('demo','l_map_sp.R', package='loon'),'\n'))
+}
\ No newline at end of file
